import pandas as pd

def load_csv_to_dataframe(file_path):
    #load csv
    return pd.read_csv(file_path)

def save_dataframe_to_csv(df, file_path, index = False):
    #saves a dataframe to csv
    df.to_csv(file_path,index = index)